<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title>{{ title }}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link id="favicon" rel="icon" href="favicon.png" type="image/png" />
    <script src="zimwriterfs.js"></script>
    <link rel="stylesheet" href="vendors/bootstrap/css/bootstrap.min.css">
    <link href="vendors/videojs/video-js.css" rel="stylesheet" />
    <link href="assets/styles.css" rel="stylesheet" type="text/css">
    <style type="text/css">
        header { background-color: {{ main_color }};}
        #loader { color: {{ main_color }};}
        footer { background-color: {{ secondary_color }};}
    </style>
  </head>
  <body>
    <header class="container-fluid">
        <div class="row">
            <div class="col-xs-12 col-sm-6">
                <a href="home.html"><img class="logo" src="assets/main-logo.png" /></a>
                <a href="#" class="btn about-btn" role="button" data-toggle="tooltip" title="{{ about_label }}">
                    <img src="assets/info-circle-solid.svg" />
                </a>
            </div>
            <form class="form-check-inline search-box col-xs-12 col-sm-6">
                <input class="form-control" type="search" placeholder="{{ search_input_label }}" id="search_text" />
                <button class="btn btn-dark ml-2">{{ search_label }}</button>
            </form>
        </div>
    </header>

    <div class="container">
        <section class="scrollable-content">
            <div id="modal" class="modal" tabindex="-1" role="dialog" aria-hidden="true">
              <div class="modal-dialog modal-dialog-scrollable modal-xs" role="document">
                <div class="modal-content">
                    <div class="modal-header"><h5 class="modal-title"></h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="{{ close_label }}">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">{{ loading_label }}</div>
                </div>
              </div>
            </div>
            <ul id="doc-list" class="event-list">
            </ul>
            <div class="no-result"><p>{{ no_result_text }}</p></div>
            <div id="loader" class="spinner-border" role="status">
                <span class="sr-only">{{ loading_label }}</span>
            </div>
        </section>
    </div>
    <a  href="#" class="btn btn-dark back-to-top"
        role="button"
        data-toggle="tooltip"
        title="{{ backtotop_label }}">⇡</span>
    </a>
    <footer>
        {% if secondary_logo %}<hr /><img src="assets/secondary-logo.png" />{% endif %}
    </footer>

    <script src="vendors/pouchdb.min.js"></script>
    <script src="vendors/pouchdb.find.min.js"></script>

    <script src="vendors/jquery.min.js"></script>
    <script src="vendors/bootstrap/js/bootstrap.bundle.min.js"></script>

    <script type="text/javascript" src="vendors/ScrollMagic.min.js"></script>

    <script src="vendors/videojs/video.js"></script>
    <script src="vendors/ogvjs/ogv-support.js"></script>
    <script src="vendors/ogvjs/ogv.js"></script>
    <script src="vendors/videojs-ogvjs.js"></script>

    <script src="vendors/handlebars.runtime.min-v4.7.6.js"></script>
    <script src="assets/templates/precompiled.js"></script>
    <script src="vendors/sugar.min.js"></script>
    <script src="nautilus.js"></script>
    <script type="text/javascript">
        $( document ).ready(function() {
            $('[data-toggle="tooltip"]').tooltip();
            window.nautilus = new Nautilus({
                title: "{{ title }}",
                description: "{{ description }}",
                database_name: "{{ db_name }}.{{ db_version }}",
                database_version: "{{ db_version }}",
                nb_items_per_page: {{ nb_items_per_page }},
                show_author: {{ show_author|lower }},
                show_description: {{ show_description|lower }},
                randomize: {{ randomize|lower }},
                debug: {{ debug }},
                i18n: {loading: "{{ loading_label}}",},
            });
            window.nautilus.start();
        });
    </script>
    <div id="about-content">
        {{about_content|safe}}
        {% if secondary_logo %}<hr /><img src="assets/secondary-logo.png" />{% endif %}
    </div>
</body>
</html>
